@@ -12,7 +12,7 @@ import shlex
 
 import simplifiedapp
 
-__version__ = '0.1.3'
+__version__ = '0.1.4'
 
 LOGGER = logging.getLogger(__name__)
 
@@ -126,25 +126,29 @@ class EnvironmentalPipes:
 		return result
 
 	@staticmethod
-	def vars_from_file(file_with_vars, sep = ' '):
+	def vars_from_file(*files_with_vars, sep = ' ', uppercase_vars = False):
 		'''Env variables from file
 		Parses a file containing the variables and prints a line, ready to be fed to "env". The file MUST be a JSON file, for now.
 		'''
 
-		file_with_vars = pathlib.Path(file_with_vars)
-		if file_with_vars.is_file():
-			LOGGER.debug('Working with file: %s', file_with_vars)
-		else:
-			raise ValueError('"{}" is not a file that you can access'.format(file_with_vars))
+		vars_values = {}
+		for file_with_vars in files_with_vars:
+			file_with_vars = pathlib.Path(file_with_vars)
+			if file_with_vars.is_file():
+				LOGGER.debug('Working with file: %s', file_with_vars)
+			else:
+				raise ValueError('"{}" is not a file that you can access'.format(file_with_vars))
+
+			#ToDo: Need some logic to detect file format. Assuming JSON for the time being.
+			file_content = json.loads(file_with_vars.read_text())
+			vars_values.update(file_content)
 
 		result = []
-
-		#ToDo: Need some logic to detect file format. Assuming JSON for the time being.
-		content = json.loads(file_with_vars.read_text())
-		for key, value in content.items():
+		for key, value in vars_values.items():
 			if isinstance(value, (list, dict)):
 				value = json.dumps(value)
-			value = shlex.quote(str(value))
-			result.append('='.join([key, value]))
+			if uppercase_vars:
+				key = key.upper()
+			result.append('='.join([key, shlex.quote(str(value))]))
 
 		return sep.join(result)
